data_latenc: Latenc data

data_latencR Documentation

Latenc data

Description

Latency times in seconds of exploratory behavior in fish during three experimental rounds.

Usage

data("data_latenc")

Format

A data frame with 40 observations on the following variables.

round 1

Latency times for round 1 of the experiment.

round 2

Latency times for round 1 of the experiment.

round 3

Latency times for round 1 of the experiment.

Kerr, Nicky R., and Travis Ingram. "Personality does not predict individual niche variation in a freshwater fish." Behavioral Ecology 32.1 (2021): 159-167.

Examples

data(data_latenc)
str(data_latenc)

# The data are used in:
## Not run: 
vignette("bixplot_examples")

## End(Not run)

classmap documentation built on April 29, 2026, 5:10 p.m.