| data_latenc | R Documentation |
Latency times in seconds of exploratory behavior in fish during three experimental rounds.
data("data_latenc")
A data frame with 40 observations on the following variables.
Latency times for round 1 of the experiment.
Latency times for round 1 of the experiment.
Latency times for round 1 of the experiment.
Kerr, Nicky R., and Travis Ingram. "Personality does not predict individual niche variation in a freshwater fish." Behavioral Ecology 32.1 (2021): 159-167.
data(data_latenc)
str(data_latenc)
# The data are used in:
## Not run:
vignette("bixplot_examples")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.